@@ -8,7 +8,8 @@
                     (set! space (d-GetUserInput (_ "Space Above Title") (_ "Give amount of space at top of title page") space))
                     (if (string? space)
                         (begin
-                            (BookTitles::DeleteInclude)
+                            ;(d-LilyPondInclude (cons 'delete "book-titling.ily"))
+                            (d-LilyPondInclude (cons 'delete "simplified-book-titling.ily"))
                             (d-DirectivePut-score-prefix tag (string-append "#(define denemo-top-margin " space ")\n"))
                             (d-DirectivePut-score-data tag space)
                             (d-DirectivePut-score-override tag DENEMO_OVERRIDE_AFFIX)
