@@ -311,6 +311,7 @@ typedef struct
   gboolean hasfigures; /**<TRUE if the staff has had figures attached. Only one staff should have this set */
   gboolean hasfakechords; /**<TRUE if the staff has had chord symbols attached. Only one staff should have this set */
   DenemoVoice voicecontrol; /**< either controls whether this staff is displayed and printed separately or as a voice */
+  gboolean hidden; /**< should this staff appear in the display? */
   measurenode ** is_parasite; /**< points to address of host staff's measures 
                  field if measures are owned by another 
                  staff */
@@ -430,6 +431,7 @@ typedef struct DenemoPrefs
   gint lastmeasure;/**< last measure to typeset relative to the cursor when not manual typset */
   gint laststaff;/**< last staff to typeset relative to the cursor when not manual typset */
   gboolean immediateplayback; /**< This options sends audio directly to synth as notes are being entered */
+  gint measureswitchsound; /**< MIDI key to play on cursor move to new measure */
   gint pitchspellingchannel; /**< channel to use for feedback when entering extreme intervals via MIDI in, that may indicate an enharmonic error, 0 means no pitch spelling*/
   gint pitchspellingprogram; /**< program to set pitchspellingchannel to on startup */
   gboolean startmidiin; /**< try to start midi in on startup */
@@ -617,7 +619,8 @@ typedef enum
   REPLACE_SCORE,
   ADD_STAFFS,
   ADD_MOVEMENTS,
-  GUIDED_IMPORT
+  GUIDED_IMPORT,
+  PROOFREAD
 } ImportType;
 
 typedef enum 
