@@ -404,15 +404,15 @@ action_note_into_score (gint mid_c_offset, gint enshift, gint octave)
 }
 
 static void
-add_note_to_chord (gint mid_c_offset, gint enshift, gint octave)
+add_or_delete_note_to_chord (gint mid_c_offset, gint enshift, gint octave)
 {
   DenemoProject *gui = Denemo.project;
+  DenemoObject *curObj;
   gui->last_source = INPUTMIDI;
   gui->movement->cursor_y = gui->movement->staffletter_y = mid_c_offset;
   gui->movement->cursor_y += 7 * octave;
-  insert_chordnote (gui);
-  // shiftcursor(gui, mid_c_offset);
-  setenshift (gui->movement, enshift);
+  if(insert_or_delete_chordnote (enshift))
+    setenshift (gui->movement, enshift);
   displayhelper (gui);
 }
 
@@ -478,7 +478,7 @@ do_one_note (gint mid_c_offset, gint enshift, gint notenum)
   if ((Denemo.keyboard_state & ADDING_MASK) && (Denemo.keyboard_state & CHORD_MASK))
     {
 
-      add_note_to_chord (mid_c_offset, enshift, notenum);
+      add_or_delete_note_to_chord (mid_c_offset, enshift, notenum);
     }
   else
     {
@@ -643,7 +643,7 @@ midiaction (gint notenum)
             {
               if (gui->movement->cursor_appending) {
                 do_one_note (enote.mid_c_offset, enote.enshift, enote.octave);
-                next_editable_note ();//if we have gone back from an appending position after a non-chord we need this
+                next_insert_or_editable_note();//next_editable_note ();//if we have gone back from an appending position after a non-chord we need this
                             }
               else
                 gdk_beep ();
@@ -660,7 +660,7 @@ midiaction (gint notenum)
       else
         {                       // no current object
           do_one_note (enote.mid_c_offset, enote.enshift, enote.octave);
-          next_editable_note ();//if we have gone back from an empty measure we need this.
+          next_insert_or_editable_note();//next_editable_note ();//if we have gone back from an empty measure we need this.
         }
     }
   else
@@ -734,12 +734,16 @@ process_midi_event (gchar * buf)
   if (command == MIDI_CONTROL_CHANGE && (notenumber == 0x40))
     {
       if (velocity == 0x7F)
-        //PEDAL DOWN
-        Denemo.keyboard_state |= ADDING_MASK;
+        {//PEDAL DOWN
+        if (Denemo.project->movement->cursor_appending)
+            Denemo.keyboard_state |= ADDING_MASK;
+        else
+            Denemo.keyboard_state |= CHORD_MASK | ADDING_MASK;
+        }
       else
         {
           Denemo.keyboard_state &= ~(CHORD_MASK | ADDING_MASK);
-          next_editable_note ();
+          next_insert_or_editable_note();//next_insert_or_editable_note ();
         }
       set_midi_in_status ();
       displayhelper (Denemo.project);
@@ -774,12 +778,15 @@ process_midi_event (gchar * buf)
                 {               //Foot Pedal
                   if (velocity == 0x7F)
                     {
-                      Denemo.keyboard_state |= ADDING_MASK;
+                    if (Denemo.project->movement->cursor_appending)
+                        Denemo.keyboard_state |= ADDING_MASK;
+                    else
+                        Denemo.keyboard_state |= CHORD_MASK | ADDING_MASK;
                     }
                   else
                     {
                       Denemo.keyboard_state &= ~(CHORD_MASK | ADDING_MASK);
-                      next_editable_note ();
+                      //next_editable_note (); this causes a double advance...
                     }
                   set_midi_in_status ();
                   displayhelper (Denemo.project);
