@@ -1218,7 +1218,35 @@ next_editable_note (void)
   return ret;
 }
 
-
+/******** advances the cursor to the next note,  stopping
+ at empty measures and at appending position if any. The cursor is left after last note if no more notes */
+gboolean
+next_insert_or_editable_note (void)
+{
+ gboolean ret;
+  if (Denemo.project->movement->currentobject && (Denemo.project->movement->currentobject->next == NULL))
+    {
+    ret = FALSE;
+    }
+  else 
+    {
+  
+    ret = to_note_direction (TRUE, TRUE);
+    if ((!ret) && Denemo.project->movement->currentobject == NULL)
+        {
+          to_note_direction (FALSE, TRUE);
+        }
+    }
+  if (!ret)
+    {
+        movecursorright (NULL, NULL);
+        if (Denemo.project->movement->currentobject == NULL)
+            movecursorleft (NULL, NULL);
+    }
+  else
+    write_status(Denemo.project);
+  return ret;
+}
 gboolean
 cursor_to_next_object (gboolean within_measure, gboolean stopping)
 {
@@ -1493,7 +1521,45 @@ shiftcursor (DenemoProject * gui, gint note_value)
           else
             {                   /* single-note chord - change the note */
               gint dclef = find_prevailing_clef (gui->movement);
-              modify_note (thechord, mid_c_offset, gui->movement->curmeasureaccs[note_value], dclef);
+              if(!thechord->is_tied)
+                modify_note (thechord, mid_c_offset, gui->movement->curmeasureaccs[note_value], dclef);
+              else //if tied modify the tied note(s) too
+                {
+                  objnode *nextobj = gui->movement->currentobject;
+                  measurenode *current = gui->movement->currentmeasure;
+                  while (1)
+                    {
+                  
+                      if(nextobj)
+                        {
+                          DenemoObject *thenextobj= (DenemoObject *) nextobj->data;
+                              
+                          if (thenextobj->type == CHORD)  
+                            {
+                                DenemoMovement *si = Denemo.project->movement;
+                                chord *next = thenextobj->object;
+                                modify_note (next, mid_c_offset, gui->movement->curmeasureaccs[note_value], dclef);
+                                calculatebeamsandstemdirs (current->data, &(si->curmeasureclef), &(si->cursortime1), &(si->cursortime2), &(si->curmeasure_stem_directive));
+                                if(next->is_tied)
+                                    {
+                                        if(nextobj->next==NULL)
+                                            {
+                                              current = current->next;
+                                              if(current && current->data)
+                                                {
+                                                   nextobj = current->data;
+                                                   continue;
+                                                }
+                                            }
+                                         nextobj = nextobj->next;
+                                         if(nextobj)
+                                            continue;
+                                    }    
+                            }
+                        }
+                    break;
+                    }
+                }
             }
           gui->movement->undo_guard--;
           score_status (gui, TRUE);
@@ -1891,7 +1957,32 @@ insert_chordnote (DenemoProject * gui)
     insert_note_following_pattern (gui);
   return TRUE;
 }
-
+/**
+ * Insert chord note at y cursor position or delete one if already present
+ * return TRUE if inserted else FALSE
+ */
+gboolean
+insert_or_delete_chordnote (gint enshift)
+{
+  DenemoProject *gui = Denemo.project;
+  DenemoObject *curObj;
+  gboolean remove = FALSE;
+  if (gui->movement->currentobject && (curObj = Denemo.project->movement->currentobject->data) && (curObj->type == CHORD))
+     {
+      GList *node;
+      for (node = ((chord *) curObj->object)->notes; node; node=node->next)
+        {
+            note *thenote = (note*)node->data;
+            if((thenote->mid_c_offset == gui->movement->cursor_y) && (thenote->enshift == enshift))
+               remove = TRUE;
+        }
+     notechange (gui->movement, remove);
+    }
+  else
+    insert_note_following_pattern (gui);
+    
+  return !remove;
+}
 /**
  * Helper function that contains calls to all the display 
  * update functions
@@ -1942,7 +2033,53 @@ incrementenshift (DenemoProject * gui, gint direction)
       shiftpitch (curmudelaobj, si->cursor_y, direction > 0);
       showwhichaccidentals ((objnode *) si->currentmeasure->data, si->curmeasurekey, si->curmeasureaccs);
       find_xes_in_measure (si, si->currentmeasurenum, si->cursortime1, si->cursortime2);
-
+      
+      
+      //if tied ...
+            chord *next = curmudelaobj->object;
+            if (next->is_tied) 
+                {
+                 objnode *nextobj = gui->movement->currentobject->next;
+                  measurenode *current = gui->movement->currentmeasure;
+                  if(nextobj==NULL)
+                        {
+                          current = current->next;
+                          if(current && current->data)
+                            {
+                               nextobj = current->data;
+                           }
+                       }
+                  while (nextobj)
+                    {
+                      DenemoObject *thenextobj= (DenemoObject *) nextobj->data;
+                          
+                      if (thenextobj->type == CHORD)  
+                        {
+                            chord *next = thenextobj->object;
+                            shiftpitch (thenextobj, si->cursor_y, direction > 0);
+                            showwhichaccidentals ((objnode *) current->data, si->curmeasurekey, si->curmeasureaccs);
+                            if(next->is_tied)
+                             {
+                                if(nextobj->next==NULL)
+                                {
+                                  current = current->next;
+                                  if(current && current->data)
+                                    {
+                                       nextobj = current->data;
+                                       continue;
+                                    }
+                                }
+                                nextobj = nextobj->next;
+                                continue;
+                            }
+                            else
+                            break;
+                        }
+                    
+                        break;
+                    }
+            
+        }
       if (Denemo.project->last_source == INPUTKEYBOARD)
         {
           DenemoStaff *curstaffstruct = (DenemoStaff *) si->currentstaff->data;
