@@ -4,14 +4,19 @@
 #include "ui/mousing.h"
 
 static gchar*
-find_command_dir(GtkAction* action, gchar* filename)
+find_command_dir(gint idx, gchar* filename)
 {
-  gchar *menupath = (gchar *) g_object_get_data (G_OBJECT (action), "menupath");
+  command_row* row = NULL;
+  keymap_get_command_row(Denemo.map, &row, idx);
+
+  if(!row->menupath)
+    g_debug("Command %s has no menupath", filename);
+  
   GList* dirs = NULL;
-  dirs = g_list_append(dirs, g_build_filename (PACKAGE_SOURCE_DIR, COMMANDS_DIR, "menus", menupath, NULL));
-  dirs = g_list_append(dirs, g_build_filename (get_user_data_dir (TRUE), COMMANDS_DIR, "menus", menupath, NULL));
-  dirs = g_list_append(dirs, g_build_filename (get_user_data_dir (TRUE), "download", COMMANDS_DIR, "menus", menupath, NULL));
-  dirs = g_list_append(dirs, g_build_filename (get_system_data_dir (), COMMANDS_DIR, "menus", menupath, NULL));
+  dirs = g_list_append(dirs, g_build_filename (PACKAGE_SOURCE_DIR, COMMANDS_DIR, "menus", row->menupath, NULL));
+  dirs = g_list_append(dirs, g_build_filename (get_user_data_dir (TRUE), COMMANDS_DIR, "menus", row->menupath, NULL));
+  dirs = g_list_append(dirs, g_build_filename (get_user_data_dir (TRUE), "download", COMMANDS_DIR, "menus", row->menupath, NULL));
+  dirs = g_list_append(dirs, g_build_filename (get_system_data_dir (), COMMANDS_DIR, "menus", row->menupath, NULL));
 
   return find_dir_for_file (filename, dirs);
 }
@@ -27,9 +32,9 @@ parseScripts (xmlDocPtr doc, xmlNodePtr cur, gchar * fallback)
 {
   command_row* command = NULL;
   xmlChar *type = NULL;
+  xmlNodePtr head = cur;
   type = xmlGetProp(cur, COMMANDXML_TAG_TYPE);
-  
-  for (cur = cur->xmlChildrenNode; cur; cur = cur->next)
+    for (cur = cur->xmlChildrenNode; cur; cur = cur->next)
     {
       if (0 == xmlStrcmp (cur->name, COMMANDXML_TAG_ACTION))
         {
@@ -50,7 +55,11 @@ parseScripts (xmlDocPtr doc, xmlNodePtr cur, gchar * fallback)
                 command->script_type = get_command_type(type);
             }
         }
-      else if (0 == xmlStrcmp (cur->name, COMMANDXML_TAG_HIDDEN))
+    }
+  cur = head;
+  for (cur = cur->xmlChildrenNode; cur; cur = cur->next)
+    {
+    if (0 == xmlStrcmp (cur->name, COMMANDXML_TAG_HIDDEN))
         {
           command->hidden = TRUE;
         }
@@ -70,8 +79,6 @@ parseScripts (xmlDocPtr doc, xmlNodePtr cur, gchar * fallback)
         {
           command->tooltip = _((gchar*) xmlNodeListGetString (doc, cur->xmlChildrenNode, 1));
         }
-      else
-        g_warning("Found XML tag '%s' reading a .commands file", cur->name);
     }
   create_command(command);
   xmlFree(type);
@@ -462,7 +469,7 @@ save_xml_keymap (gchar * filename)      //_!!! create a DEV version here, saving
       {
         // Check if the command metada file exists
         cfilename = g_strconcat (basename, XML_EXT, NULL);
-        dir = find_command_dir(action, cfilename);
+        dir = find_command_dir(i, cfilename);
         g_free(cfilename);
         if(!dir)
         {
@@ -472,7 +479,7 @@ save_xml_keymap (gchar * filename)      //_!!! create a DEV version here, saving
 
         // Check if the command data file exists
         cfilename = g_strconcat (basename, SCM_EXT, NULL);
-        dir = find_command_dir(action, cfilename);
+        dir = find_command_dir(i, cfilename);
         g_free(cfilename);
         if(!dir)
         {
@@ -495,10 +502,8 @@ save_xml_keymap (gchar * filename)      //_!!! create a DEV version here, saving
       if (row->deleted)              //store as hidden in commands file
         xmlNewTextChild (child, NULL, COMMANDXML_TAG_HIDDEN, (xmlChar *) "true");
 
-
-      gchar *menupath = action ? g_object_get_data (action, "menupath") : NULL;
-      if (menupath)
-        xmlNewTextChild (child, NULL, COMMANDXML_TAG_MENUPATH, (xmlChar *) menupath);
+      if (row->menupath)
+        xmlNewTextChild (child, NULL, COMMANDXML_TAG_MENUPATH, (xmlChar *) row->menupath);
 
       gchar *label = (gchar *) lookup_label_from_idx (the_keymap, i);
       if (label)
@@ -726,16 +731,16 @@ save_command_data (gchar * filename, gchar * myscheme)
 }
 
 gchar *
-load_command_data (GtkAction * action)
+load_command_data (gint idx)
 {
-  const gchar *basename = gtk_action_get_name (action);
+  gchar *basename = lookup_name_from_idx (Denemo.map, idx);
   gchar *filename = g_strconcat (basename, SCM_EXT, NULL);
   gchar* path = NULL;
   gchar* scheme = NULL;
   GError* error = NULL;
 
   // Locate the script
-  gchar* dir = find_command_dir(action, filename);
+  gchar* dir = find_command_dir(idx, filename);
   if(!dir)
   {
     gchar* msg = g_strdup_printf(_("Unable to locate the script %s"), filename);
@@ -757,8 +762,6 @@ load_command_data (GtkAction * action)
     return NULL;
   }
   g_free(path);
-
-  g_object_set_data (G_OBJECT (action), "scheme", scheme);
   
   // Load the init script if there is one
   path = g_build_filename (dir, INIT_SCM, NULL);
