@@ -84,7 +84,9 @@ void
 add_font_directory (gchar * fontpath)
 {
 #ifdef G_OS_WIN32
-  AddFontResource (fontpath);
+  if (0 == AddFontResource (fontpath))
+    g_warning("Failed to add font dir %s.", fontpath);
+  SendMessage (HWND_BROADCAST, WM_FONTCHANGE, 0, 0);
 #endif
   if(FcConfigAppFontAddDir (NULL, (FcChar8*) fontpath) == FcFalse)
     g_warning("Failed to add font dir %s.", fontpath);
@@ -94,7 +96,9 @@ void
 add_font_file (gchar * fontname)
 {
 #ifdef G_OS_WIN32
-  AddFontResource (fontname);
+  if (0 == AddFontResource (fontname))
+    g_warning("Failed to add font file %s.", fontname);
+  SendMessage (HWND_BROADCAST, WM_FONTCHANGE, 0, 0);
 #endif
   if(FcConfigAppFontAddFile (NULL, (FcChar8*) fontname) == FcFalse)
     g_warning("Failed to add font file %s.", fontname);
@@ -2620,7 +2624,9 @@ initialize_keystroke_help (void)
       gtk_window_set_keep_above (GTK_WINDOW (KeyStrokes), TRUE);
       gtk_window_set_accept_focus (GTK_WINDOW (KeyStrokes), FALSE);
       KeyStrokeLabel = gtk_label_new ("");
+      //gtk_label_set_line_wrap (KeyStrokeLabel, TRUE);
       KeyStrokeHelp = gtk_label_new ("");
+      gtk_label_set_line_wrap (KeyStrokeHelp, TRUE);
       GtkWidget *vbox = gtk_vbox_new (FALSE, 8);
       gtk_container_add (GTK_CONTAINER (KeyStrokes), vbox);
       gtk_box_pack_start (GTK_BOX (vbox), KeyStrokeLabel, FALSE, TRUE, 0);
@@ -2735,6 +2741,7 @@ get_local_dir(DenemoDirectory dir)
     case DENEMO_DIR_PIXMAPS:    return PIXMAPS_DIR;
     case DENEMO_DIR_FONTS:      return FONTS_DIR;
     case DENEMO_DIR_LOCALE:     return LOCALE_DIR;
+    case DENEMO_DIR_LILYPOND_INCLUDE:     return LILYPOND_INCLUDE_DIR;
     default:         return NULL;
   }
 }
@@ -2748,6 +2755,7 @@ get_system_dir(DenemoDirectory dir)
     case DENEMO_DIR_UI:
     case DENEMO_DIR_SOUNDFONTS:
     case DENEMO_DIR_FONTS:
+    case DENEMO_DIR_LILYPOND_INCLUDE:
       return g_build_filename(get_system_data_dir (), get_local_dir(dir), NULL);
     case DENEMO_DIR_PIXMAPS:
       return g_build_filename(get_system_data_dir (), PIXMAPS_DIR, NULL);
@@ -2797,6 +2805,7 @@ get_executable_dir ()
  *  - in the executable parent directory
  *  - in the user directory
  *  - in the system directory
+ *  - in the system fonts directory
  **/
 gchar*
 find_denemo_file (DenemoDirectory dir, gchar* filename)
@@ -2807,7 +2816,7 @@ find_denemo_file (DenemoDirectory dir, gchar* filename)
   dirs = g_list_append(dirs, g_build_filename(get_executable_dir (), "..", get_local_dir (dir), NULL));
   dirs = g_list_append(dirs, g_build_filename(get_user_data_dir (TRUE), get_local_dir (dir), NULL));
   dirs = g_list_append(dirs, g_strdup(get_system_dir(dir)));
- 
+  dirs = g_list_append(dirs, g_build_filename(get_executable_dir (), "..", "share","fonts","truetype","denemo", NULL));
   return find_path_for_file (filename, dirs);
 }
 
