@@ -711,7 +711,7 @@ draw_measure (cairo_t * cr, measurenode * curmeasure, gint x, gint y, DenemoProj
         {                       //don't draw meassure number 1, as it collides and is obvious anyway and is never typeset thus
           cairo_set_source_rgba (cr, 0, 0, 0, 0.5);
           g_string_sprintf (mstring, "%d", itp->measurenum);
-          drawnormaltext_cr (cr, mstring->str, x - SPACE_FOR_BARLINE + 5, y - 3);
+          drawnormaltext_cr (cr, mstring->str, x - SPACE_FOR_BARLINE - 5, y - 3);
         }
     }
 
@@ -798,6 +798,10 @@ draw_measure (cairo_t * cr, measurenode * curmeasure, gint x, gint y, DenemoProj
             } 
       if (curmeasure->data)
         {
+            
+            if (extra_ticks == -itp->tickspermeasure)
+                extra_ticks = 0;//allow empty measures
+            
           if (extra_ticks > 0)
                 cairo_set_source_rgba (cr, 1.0, 0.6, 0.6, OPACITY);
           else if ((extra_ticks < 0)/* && curmeasure->next*/)
@@ -1333,9 +1337,22 @@ draw_score (cairo_t * cr)
     cairo_translate (cr, 0.5, 0.5);
  
   /* Draw each staff */
-  for (itp.staffnum = si->top_staff, curstaff = g_list_nth (si->thescore, si->top_staff - 1), (y += si->staffspace / 4); curstaff && itp.staffnum <= si->bottom_staff; itp.staffnum++)
+  for (itp.staffnum = si->top_staff, curstaff = g_list_nth (si->thescore, si->top_staff - 1), (y += si->staffspace / 4); curstaff && itp.staffnum <= si->bottom_staff;  curstaff = curstaff->next, itp.staffnum++)
     {
       DenemoStaff *staff = (DenemoStaff *) curstaff->data;
+      if(cr) if (staff->hidden) 
+      {
+        gboolean current =  (si->currentstaffnum == itp.staffnum);
+
+        cairo_save (cr);
+        cairo_set_source_rgba (cr, 0.0, 0.5, 0.5, current?1.0:0.5);
+        cairo_rectangle (cr, 0, itp.staffnum == si->top_staff? 5 : y - 35, get_widget_width (Denemo.scorearea) / Denemo.project->movement->zoom, 1 + 8*current); 
+        cairo_fill (cr);
+        cairo_restore (cr);  
+        if (current)
+            drawtext_cr (cr, _("Current staff is hidden - do not edit!"), 20.0, 100.0, 48.0);
+        continue;
+      }
       itp.verse = verse_get_current_view (staff);
       GdkPixbuf *StaffDirectivesPixbuf = (si->currentstaffnum == itp.staffnum) ? StaffPixbuf : StaffPixbufSmall;
       if (si->currentstaffnum == itp.staffnum)
@@ -1573,7 +1590,7 @@ draw_score (cairo_t * cr)
             }
           y += (si->staffspace + staff->space_below);
         }
-      curstaff = curstaff->next;
+     
     }                           // for all the staffs
 
   //g_debug("Right most time %f\n", si->rightmost_time);
@@ -1617,7 +1634,9 @@ draw_callback (cairo_t * cr)
  }
 #endif
   /* Clear with an appropriate background color. */
-  if (Denemo.project->input_source != INPUTKEYBOARD && Denemo.project->input_source != INPUTMIDI && (Denemo.prefs.overlays || (Denemo.project->input_source == INPUTAUDIO)) && pitch_entry_active (gui))
+  if (((DenemoStaff*)Denemo.project->movement->currentstaff->data)->hidden)
+    cairo_set_source_rgb (cr, 1, 0.8, 0.8);
+  else if (Denemo.project->input_source != INPUTKEYBOARD && Denemo.project->input_source != INPUTMIDI && (Denemo.prefs.overlays || (Denemo.project->input_source == INPUTAUDIO)) && pitch_entry_active (gui))
     {
       GdkColor col;
       gdk_color_parse ("lightblue", &col);
@@ -1632,16 +1651,14 @@ draw_callback (cairo_t * cr)
       else
         cairo_set_source_rgb (cr, ((0xFF0000 & Denemo.color) >> 16) / 255.0, ((0xFF00 & Denemo.color) >> 8) / 255.0, ((0xFF & Denemo.color)) / 255.0);
     }
+
   else
     {
       cairo_set_source_rgb (cr, 0.8, 0.8, 0.8); //gray background when key strokes are not being received.
     }
   cairo_paint (cr);
-
   /* Draw the score. */
   draw_score (cr);
-
-
   return TRUE;
 }
 
