@@ -116,7 +116,10 @@ supported_file_extensions(gchar* format){
     exts = g_list_append(exts, "*.pdf");
     exts = g_list_append(exts, "*.PDF");
   }
-
+  if(g_strcmp0 ("proof", format) == 0){
+    exts = g_list_append(exts, "*.pdf");
+    exts = g_list_append(exts, "*.PDF");
+  }
   return exts;
 }
 
@@ -353,7 +356,7 @@ open_for_real (gchar * filename, DenemoProject * gui, DenemoSaveType template, I
 #else
           // a .pdf file for transcribing from, does not affect the current score.
           g_signal_handlers_unblock_by_func (G_OBJECT (Denemo.scorearea), G_CALLBACK (scorearea_draw_event), NULL);
-          return !open_source (filename, 0, 0, 0);
+          return type==PROOFREAD? (!open_proofread_file(filename)) : !open_source (filename, 0, 0, 0);
 #endif
         }
     g_message("Opening file %s", filename);
@@ -829,7 +832,7 @@ update_preview_cb (GtkFileChooser * file_chooser, gpointer data)
 
   gtk_image_set_from_pixbuf (GTK_IMAGE (preview), pixbuf);
   if (pixbuf)
-    gdk_pixbuf_unref (pixbuf);
+    g_object_unref (pixbuf);
 
   gtk_file_chooser_set_preview_widget_active (file_chooser, have_preview);
 #endif
@@ -902,6 +905,11 @@ open_source_file (void)
 {
   return file_open_dialog ("Open", "evince", PDF_FORMAT, 0, 0, NULL);
 }
+gint
+open_proof_file (void)
+{
+  return file_open_dialog ("Open", "proof", PDF_FORMAT, 0, PROOFREAD, NULL);
+}
 
 /**
  * Lilypond Import dialog - opened where appropriate 
@@ -1215,7 +1223,7 @@ file_savepartswrapper (GtkAction * action, DenemoScriptParam * param)
 
 
 static void
-selection_received (G_GNUC_UNUSED GtkClipboard * clipboard, const gchar * text, G_GNUC_UNUSED gpointer data)
+lilypond_selection_received (G_GNUC_UNUSED GtkClipboard * clipboard, const gchar * text, G_GNUC_UNUSED gpointer data)
 {
   if (!text)
     {
@@ -1270,10 +1278,46 @@ paste_clipboard (GtkAction * action, DenemoScriptParam * param)
       return;
     }
   GtkClipboard *clipboard = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
-  gtk_clipboard_request_text (clipboard, (GtkClipboardTextReceivedFunc) selection_received, NULL);
+  gtk_clipboard_request_text (clipboard, (GtkClipboardTextReceivedFunc) lilypond_selection_received, NULL);
 
 }
 
+static void
+comment_selection_received (G_GNUC_UNUSED GtkClipboard * clipboard, const gchar * text)
+{
+ gchar *comment;
+ GString *exceptions = g_string_new ("");
+ gint i;
+ for (i=0x1;i<0x10;i++)
+    g_string_append_printf (exceptions, "%c", i);
+  for (i=0x7F;i<0x100;i++)
+    g_string_append_printf (exceptions, "%c", i);
+    
+  if ((!text) || (*text == 0))
+    {
+      warningdialog (_("No selection text available"));
+      return;
+    }
+    gchar *escaped = g_strescape(text, exceptions->str);
+    gchar *info = g_strconcat(_("Inserted:\n"), escaped, NULL);
+    comment = g_strdup_printf ("(d-Comment \"%s\")(d-InfoDialog \"%s\")", escaped, info);
+    call_out_to_guile (comment);
+    g_string_free (exceptions, TRUE);
+    g_free (escaped);
+    g_free (info);
+    g_free (comment);
+}
+void
+paste_comment (GtkAction * action, DenemoScriptParam * param)
+{
+    if(param && param->string && param->string->len)
+        comment_selection_received (NULL, param->string->str);
+    else 
+        {
+        GtkClipboard *clipboard = gtk_clipboard_get (GDK_SELECTION_CLIPBOARD);
+        gtk_clipboard_request_text (clipboard, (GtkClipboardTextReceivedFunc) comment_selection_received, NULL);
+        }
+}
 static void
 export_interface(GtkAction* action, DenemoScriptParam* param, gint format_id){
   GET_1PARAM(action, param, filename);
