@@ -84,6 +84,8 @@ SCM scheme_has_selection (void);
 SCM scheme_is_appending (void);
 SCM scheme_shift_cursor (SCM);
 SCM scheme_get_movement (void);
+SCM scheme_get_voice_identifier (void);
+SCM scheme_staff_hidden (SCM set);
 SCM scheme_get_staff (void);
 SCM scheme_get_measure (void);
 SCM scheme_set_object_display_width (SCM);
@@ -299,6 +301,7 @@ SCM scheme_edit_graphics (SCM, SCM);
 SCM scheme_open_source (SCM);
 SCM scheme_export_recorded_audio (void);
 SCM scheme_open_source_file (SCM);
+SCM scheme_open_proofread_file (SCM);
 SCM scheme_open_source_audio_file (SCM);
 SCM scheme_close_source_audio (SCM);
 SCM scheme_start_audio_play (SCM);
@@ -363,9 +366,26 @@ SCM scheme_paper_directive_get_nth_tag (SCM);
 SCM scheme_layout_directive_get_nth_tag (SCM);
 SCM scheme_movementcontrol_directive_get_nth_tag (SCM);
 
+SCM scheme_edit_system_directive (void);
 SCM scheme_directive_get_nth_tag_strict_note (SCM);
 SCM scheme_directive_get_for_tag_strict_note (SCM);
 
+SCM scheme_chord_directive_prioritize_tag (SCM);
+SCM scheme_note_directive_prioritize_tag (SCM);
+SCM scheme_staff_directive_prioritize_tag (SCM);
+SCM scheme_voice_directive_prioritize_tag (SCM);
+SCM scheme_score_directive_prioritize_tag (SCM);
+SCM scheme_clef_directive_prioritize_tag (SCM);
+SCM scheme_timesig_directive_prioritize_tag (SCM);
+SCM scheme_tuplet_directive_prioritize_tag (SCM);
+SCM scheme_stemdirective_directive_prioritize_tag (SCM);
+SCM scheme_keysig_directive_prioritize_tag (SCM);
+SCM scheme_scoreheader_directive_prioritize_tag (SCM);
+SCM scheme_header_directive_prioritize_tag (SCM);
+SCM scheme_paper_directive_prioritize_tag (SCM);
+SCM scheme_layout_directive_prioritize_tag (SCM);
+SCM scheme_movementcontrol_directive_prioritize_tag (SCM);
+
 
 SCM scheme_delete_note_directive (SCM);
 SCM scheme_activate_note_directive (SCM);
