@@ -23,6 +23,9 @@ static gboolean lh_down;
 static gdouble last_event_x;
 static gdouble last_event_y;
 static DenemoDirective *last_directive;
+typedef enum DragDirection { DRAG_DIRECTION_NONE = 0, DRAG_DIRECTION_UP, DRAG_DIRECTION_DOWN, DRAG_DIRECTION_LEFT, DRAG_DIRECTION_RIGHT} DragDirection;
+static enum DragDirection dragging_outside = DRAG_DIRECTION_NONE; //dragging to left or right outside window.
+
 /**
  * Get the mid_c_offset of an object or click from its height relative
  * to the top of the staff.  
@@ -90,6 +93,7 @@ get_click_height (DenemoProject * gui, gdouble y)
     {
       //g_debug("before extra space %d\n", extra_space);
       staff = (DenemoStaff *) curstaff->data;
+      if (staff->hidden) continue;
       if (staff->voicecontrol & DENEMO_PRIMARY)
         extra_space += (staff->space_above) + space_below;
       if (curstaff == gui->movement->currentstaff)
@@ -164,8 +168,8 @@ staff_at (gint y, DenemoMovement * si)
       DenemoStaff *staff = (DenemoStaff *) curstaff->data;
 
       count++;
-      if (staff->voicecontrol & DENEMO_PRIMARY)
-        space += (staff)->space_above + (staff)->space_below + si->staffspace;
+      if ((!staff->hidden) && (staff->voicecontrol & DENEMO_PRIMARY))
+        space += staff->space_above + staff->space_below + si->staffspace + (staff->verse_views ? LYRICS_HEIGHT : 0);
       //g_debug("y %d and space %d count = %d\n",y,space, count);
     }
 
@@ -398,10 +402,38 @@ transform_coords (double *x, double *y)
   // *x += ((double)line_num * gui->movement->widthtoworkwith / ((int)(1/gui->movement->system_height))) - 1.0* (line_num?(double)LEFT_MARGIN:0.0);
 }
 
-
+static void extend_selection (DragDirection direction)
+{
+   switch (direction) {
+       case DRAG_DIRECTION_RIGHT:
+        cursorright (NULL, NULL);
+        break;
+      case DRAG_DIRECTION_LEFT:
+        cursorleft (NULL, NULL);
+        break;
+      case DRAG_DIRECTION_UP:
+        staffup (NULL, NULL);
+        move_viewport_up (Denemo.project);
+        break;
+      case DRAG_DIRECTION_DOWN:
+        staffdown (NULL, NULL);
+        move_viewport_down (Denemo.project);
+        break;
+    }
+        
+    gtk_widget_queue_draw(Denemo.scorearea);
+}
 gint
 scorearea_leave_event (GtkWidget * widget, GdkEventCrossing * event)
 {
+    gint allocated_height = get_widget_height (Denemo.scorearea);
+    gint allocated_width = get_widget_width (Denemo.scorearea);
+  if (event->state & GDK_BUTTON1_MASK)
+    {
+       dragging_outside = (event->x>=allocated_width)?DRAG_DIRECTION_RIGHT:(event->x < 0)?DRAG_DIRECTION_LEFT:(event->y < 0)? DRAG_DIRECTION_UP : DRAG_DIRECTION_DOWN;
+       last_event_x = event->x_root;
+       last_event_y = event->y_root;
+    }
   gdk_window_set_cursor (gtk_widget_get_window (Denemo.window), gdk_cursor_new (GDK_LEFT_PTR)); //FIXME? does this take time/hog memory
   return FALSE;                 //allow other handlers (specifically the pitch entry one)
 }
@@ -409,6 +441,7 @@ scorearea_leave_event (GtkWidget * widget, GdkEventCrossing * event)
 gint
 scorearea_enter_event (GtkWidget * widget, GdkEventCrossing * event)
 {
+  dragging_outside = DRAG_DIRECTION_NONE;
   if(Denemo.keyboard_state_locked) return FALSE;
 //g_debug("start the enter with ks = %x and state %x\n", Denemo.keyboard_state, event->state);
   if (event->state & GDK_CONTROL_MASK)
@@ -446,7 +479,27 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
     return FALSE;
   gint allocated_height = get_widget_height (Denemo.scorearea);
   gint line_height = allocated_height * gui->movement->system_height;
-  
+  if(dragging_outside)
+    {
+          gint incrx, incry;
+          incrx=incry=0;
+          if(((gint)((last_event_x - event->x_root)/gui->movement->zoom)) != 0)
+            {
+                incrx = -(last_event_x - event->x_root)/gui->movement->zoom;
+                last_event_x = event->x_root;
+            }
+          if( ((gint)((last_event_y - event->y_root)/gui->movement->zoom)) != 0)
+            {
+                incry = -(last_event_y - event->y_root)/gui->movement->zoom;
+                last_event_y = event->y_root;
+            }    
+        if((dragging_outside==DRAG_DIRECTION_RIGHT) && (incrx > 1)
+            || ((dragging_outside==DRAG_DIRECTION_LEFT) && (incrx < -1))
+            || ((dragging_outside==DRAG_DIRECTION_UP) && (incry < 0))
+            || ((dragging_outside==DRAG_DIRECTION_DOWN) && (incry > 0)))
+            extend_selection(dragging_outside);
+    return TRUE;
+    }
   if (event->y < 0)
     event->y = 0.0;
   gint line_num = ((int) event->y) / line_height;
@@ -580,7 +633,10 @@ scorearea_motion_notify (GtkWidget * widget, GdkEventButton * event)
           set_cursor_y_from_click (gui, event->y);
           if (lh_down & !selecting)
             {
-              set_mark (NULL, NULL);
+              if (gui->movement->markstaffnum)
+                set_point (NULL, NULL);
+              else
+                set_mark (NULL, NULL);
               selecting = TRUE;
             }
           calcmarkboundaries (gui->movement);
