@@ -24,6 +24,7 @@
 #include "ui/texteditors.h"
 #include <librsvg/rsvg.h>
 
+
 #if GTK_MAJOR_VERSION==2
 #define gtk_grid_new() (pal->rows?gtk_hbox_new (FALSE, 1):gtk_vbox_new (FALSE, 1))
 #define gtk_grid_attach(widget, obj, a,b,c,d) gtk_box_pack_start(widget, obj, FALSE, TRUE, 0)
@@ -103,8 +104,11 @@ void repack_palette (DenemoPalette *pal)
     {
         gtk_window_resize (GTK_WINDOW(pal->window), 1, 1);
         gtk_widget_show (pal->window);
+        gtk_widget_set_can_focus (pal->window, FALSE);
+        switch_back_to_main_window ();
     }
     gtk_widget_show(pal->box);
+   
 }
 
 
@@ -293,7 +297,13 @@ static void copy_button (GtkWidget *button) {
         palette_add_button (pal, label, tooltip, script);
     }
 }
-
+static void duplicate_button (GtkWidget *button) {
+    DenemoPalette *pal = g_object_get_data (G_OBJECT(button), "palette");
+    gchar *tooltip =  gtk_widget_get_tooltip_text (button);
+    gchar *label = _("Duplicate Button");
+    gchar *script = g_object_get_data (G_OBJECT(button), "script");
+    palette_add_button (pal, label, tooltip, script);
+}
 static void popup_button_menu(DenemoPalette *pal, GtkWidget *button) {
   GtkWidget *menu = gtk_menu_new ();
   GtkWidget *item;
@@ -315,6 +325,11 @@ static void popup_button_menu(DenemoPalette *pal, GtkWidget *button) {
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
   g_signal_connect_swapped (G_OBJECT (item), "activate", G_CALLBACK (copy_button), (gpointer) button);
   
+  item = gtk_menu_item_new_with_label (_("Duplicate this button"));
+  gtk_widget_set_tooltip_text (item, _("Create a new button with the same effect"));
+  gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
+  g_signal_connect_swapped (G_OBJECT (item), "activate", G_CALLBACK (duplicate_button), (gpointer) button); 
+  
   item = gtk_menu_item_new_with_label (_("Remove from Palette"));
   gtk_widget_set_tooltip_text (item, _("Remove this button from this palette"));
   gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
@@ -377,6 +392,7 @@ DenemoPalette *get_palette (gchar *name)
 
 static button_pressed (GtkWidget *button, GdkEventButton  *event, DenemoPalette *pal)
 { 
+    Denemo.currentpalette = pal;
     if (event->button == 1)
         return FALSE;
     popup_button_menu(pal, button);
@@ -423,6 +439,8 @@ gboolean palette_add_button (DenemoPalette *pal, gchar *label, const gchar *tool
     g_signal_connect_swapped ( G_OBJECT (button), "clicked", G_CALLBACK (call_out_to_guile), thescript);
     g_signal_connect_after ( G_OBJECT (button), "clicked", G_CALLBACK (switch_back_to_main_window), NULL);
     g_signal_connect (G_OBJECT (button), "button-press-event", G_CALLBACK (button_pressed), (gpointer)pal);
+    Denemo.currentpalette = pal;
+
     return TRUE;
 }
 
@@ -433,7 +451,30 @@ void palette_delete_button (DenemoPalette *pal, GtkWidget *button)
     gtk_widget_destroy(button);
 }
 
-
+gboolean palette_action_button (DenemoPalette *pal, gchar *label)
+{
+    gboolean ret = FALSE;
+    GList *g;
+    for (g=pal->buttons;g;g=g->next)
+    {
+        GtkWidget *button = g->data;
+        const gchar *this = gtk_button_get_label (GTK_BUTTON(button));
+        if (*this=='<')
+           {
+            while (*this && *this != '>')
+                this++;
+            if(*this) this++;
+            }
+           // g_print ("this %s and %s %d\n", this, label,  g_str_has_prefix (this, label));
+        if(*this && g_str_has_prefix (this, label))
+            {
+            ret = gtk_widget_activate (button);
+            break;
+            }
+    }
+    Denemo.currentpalette = pal;
+    return ret;
+}
 DenemoPalette *create_palette (gchar *name, gboolean docked, gboolean rows) {
     DenemoPalette *pal = get_palette (name);
     
@@ -456,7 +497,8 @@ DenemoPalette *create_palette (gchar *name, gboolean docked, gboolean rows) {
             gtk_widget_show (pal->window);
             gtk_container_add (GTK_CONTAINER (pal->window), pal->box);
         }
-    }   
+    }  
+    Denemo.currentpalette = pal;
     return pal;
 }
 
@@ -468,6 +510,7 @@ DenemoPalette *set_palate_shape (gchar *name, gboolean row_wise, gint limit)
         pal->rows = row_wise;
         repack_palette (pal);
         //gtk_window_resize (GTK_WINDOW (window), 1, 1);
+        Denemo.currentpalette = pal;
         return pal;
     }
   return NULL;
@@ -479,6 +522,7 @@ void delete_palette (DenemoPalette *pal) {
         palette_delete_button (pal, GTK_WIDGET(g->data));
     gtk_widget_destroy (gtk_widget_get_parent (pal->box));//FIXME if docked this will not be a toplevel
     Denemo.palettes = g_list_remove (Denemo.palettes, pal);
+    Denemo.currentpalette = NULL;
 }
 
 static gchar *selected_palette_name = NULL;
